@@ -144,8 +144,8 @@ static gboolean create_dialog()
 	val = alertpanel_full(_("Find address book email duplicates"),
 	                      _("Claws Mail will now search for duplicate email "
 	                        "addresses in the address book."),
-	                      GTK_STOCK_CANCEL,GTK_STOCK_FIND,NULL, FALSE, vbox, ALERT_NOTICE,
-	                      G_ALERTALTERNATE);
+	                      GTK_STOCK_CANCEL,GTK_STOCK_FIND, NULL,
+												ALERTFOCUS_SECOND, FALSE, vbox, ALERT_NOTICE);
 	if(val == G_ALERTALTERNATE) {
 		want_search = TRUE;
 
@@ -514,8 +514,7 @@ static gboolean is_editing_entry_only_selection(void)
 		return FALSE;
 
 	selected = gtk_tree_selection_get_selected_rows(sel_detail,&model);
-	if(!selected)
-		return FALSE;
+	cm_return_val_if_fail(selected, FALSE);
 
 	gtk_tree_model_get_iter(model, &iter, (GtkTreePath*)selected->data);
 	g_list_foreach(selected, (GFunc)gtk_tree_path_free, NULL);
@@ -786,13 +785,12 @@ static void cb_del_btn_clicked(GtkButton *button, gpointer data)
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(detail_view));
 
 	list = gtk_tree_selection_get_selected_rows(selection, &model);
-
-	if(!list)
-		return;
+	cm_return_if_fail(list);
 
 	aval = alertpanel(_("Delete address(es)"),
 	                  _("Really delete the address(es)?"),
-	                  GTK_STOCK_CANCEL, "+"GTK_STOCK_DELETE, NULL);
+	                  GTK_STOCK_CANCEL, GTK_STOCK_DELETE, NULL,
+										ALERTFOCUS_SECOND);
 	if(aval != G_ALERTALTERNATE)
 		return;
 
@@ -841,7 +839,7 @@ gboolean addrduplicates_delete_item_person(ItemPerson *item, AddressDataSource *
 	if( iface && iface->readOnly ) {
 		alertpanel( _("Delete address"),
 		            _("This address data is readonly and cannot be deleted."),
-		            GTK_STOCK_CLOSE, NULL, NULL );
+		            GTK_STOCK_CLOSE, NULL, NULL, ALERTFOCUS_FIRST );
 		return FALSE;
 	}
 
