@@ -146,6 +146,8 @@ GSourceFuncs ssl_watch_funcs = {
 	ssl_sock_prepare,
 	ssl_sock_check,
 	ssl_sock_dispatch,
+	NULL,
+	NULL,
 	NULL
 };
 #endif
@@ -587,7 +589,7 @@ static gint sock_connect_with_timeout(gint sock,
 				      gint addrlen,
 				      guint timeout_secs)
 {
-	gint ret;
+	gint ret, saved_errno;
 #ifdef G_OS_UNIX
 	void (*prev_handler)(gint);
 	
@@ -604,6 +606,12 @@ static gint sock_connect_with_timeout(gint sock,
 #endif
 
 	ret = connect(sock, serv_addr, addrlen);
+	saved_errno = errno;
+
+	if (ret == -1) {
+		debug_print("connect() failed: %d (%s)\n",
+				saved_errno, g_strerror(saved_errno));
+	}
 
 #ifdef G_OS_UNIX
 	alarm(0);
