@@ -205,7 +205,7 @@ static void import_ok_cb(GtkWidget *widget, gpointer data)
 	}
 	if (destdir && !*destdir) {
 		if (alertpanel(_("Import mbox file"), _("Destination folder is not set.\nImport mbox file to the Inbox folder?"),
-						GTK_STOCK_OK, GTK_STOCK_CANCEL, NULL)
+						GTK_STOCK_OK, GTK_STOCK_CANCEL, NULL, ALERTFOCUS_FIRST)
 			== G_ALERTALTERNATE) {
 			gtk_widget_grab_focus(dest_entry);
 			return;
