@@ -49,6 +49,7 @@
 #include "tags.h"
 #include "folder_item_prefs.h"
 #include "procmsg.h"
+#include "file-utils.h"
 
 /*!
  *\brief	Keyword lookup element
@@ -112,6 +113,8 @@ static const MatchParser matchparser_tab[] = {
 	{MATCHCRITERIA_AGE_LOWER, "age_lower"},
 	{MATCHCRITERIA_AGE_GREATER_HOURS, "age_greater_hours"},
 	{MATCHCRITERIA_AGE_LOWER_HOURS, "age_lower_hours"},
+	{MATCHCRITERIA_DATE_AFTER, "date_after"},
+	{MATCHCRITERIA_DATE_BEFORE, "date_before"},
 	{MATCHCRITERIA_NEWSGROUPS, "newsgroups"},
 	{MATCHCRITERIA_NOT_NEWSGROUPS, "~newsgroups"},
 	{MATCHCRITERIA_MESSAGEID, "messageid"},
@@ -322,6 +325,7 @@ MatcherProp *matcherprop_new(gint criteria, const gchar *header,
 #ifndef G_OS_WIN32
 	prop->preg = NULL;
 #endif
+	prop->casefold_expr = NULL;
 	prop->value = value;
 	prop->error = 0;
 
@@ -343,6 +347,7 @@ void matcherprop_free(MatcherProp *prop)
 		regfree(prop->preg);
 		g_free(prop->preg);
 	}
+	g_free(prop->casefold_expr);
 #endif
 	g_free(prop);
 }
@@ -366,6 +371,7 @@ MatcherProp *matcherprop_copy(const MatcherProp *src)
 #ifndef G_OS_WIN32
 	prop->preg = NULL; /* will be re-evaluated */
 #endif
+	prop->casefold_expr = src->casefold_expr ? g_strdup(src->casefold_expr) : NULL;
 	prop->value = src->value;
 	prop->error = src->error;	
 	return prop;		
@@ -473,7 +479,7 @@ static gboolean matcherprop_string_match(MatcherProp *prop, const gchar *str,
 					 const gchar *debug_context)
 {
 	gchar *str1;
-	gchar *down_expr;
+	const gchar *down_expr;
 	gboolean ret = FALSE;
 	gboolean should_free = FALSE;
 	if (str == NULL)
@@ -482,7 +488,11 @@ static gboolean matcherprop_string_match(MatcherProp *prop, const gchar *str,
 	if (prop->matchtype == MATCHTYPE_REGEXPCASE ||
 	    prop->matchtype == MATCHTYPE_MATCHCASE) {
 		str1 = g_utf8_casefold(str, -1);
-		down_expr = g_utf8_casefold(prop->expr, -1);
+		if (!prop->casefold_expr) {
+			prop->casefold_expr = g_utf8_casefold(prop->expr, -1);
+		}
+		down_expr = prop->casefold_expr;
+
 		should_free = TRUE;
 	} else {
 		str1 = (gchar *)str;
@@ -567,7 +577,6 @@ static gboolean matcherprop_string_match(MatcherProp *prop, const gchar *str,
 free_strs:
 	if (should_free) {
 		g_free(str1);
-		g_free(down_expr);
 	}
 	return ret;
 }
@@ -730,7 +739,9 @@ static gboolean matcherprop_match_test(const MatcherProp *prop,
 		debug_print("waiting for test thread\n");
 		while(!td->done) {
 			/* don't let the interface freeze while waiting */
-			claws_do_idle();
+			if (time(NULL) - start_time > 0) {
+				claws_do_idle();
+			}
 			if (time(NULL) - start_time > 30) {
 				pthread_cancel(pt);
 				td->done = TRUE;
@@ -930,6 +941,27 @@ static gboolean matcherprop_match(MatcherProp *prop,
 		}
 		return ret;
 	}
+	case MATCHCRITERIA_DATE_AFTER:
+	{
+		gboolean ret;
+
+		ret = prop->value < info->date_t;
+
+		/* debug output */
+		if (debug_filtering_session
+				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+			if (ret) {
+				log_print(LOG_DEBUG_FILTERING,
+						"message date [ %ld ] is after [ %d ]\n",
+						info->date_t, prop->value);
+			} else {
+				log_print(LOG_DEBUG_FILTERING,
+						"message date [ %ld ] is not after [ %d ]\n",
+						info->date_t, prop->value);
+			}
+		}
+		return ret;
+	}
 	case MATCHCRITERIA_AGE_LOWER:
 		age_mult_hours = 24;
 		/* Fallthrough intended */
@@ -957,6 +989,27 @@ static gboolean matcherprop_match(MatcherProp *prop,
 		}
 		return ret;
 	}
+	case MATCHCRITERIA_DATE_BEFORE:
+	{
+		gboolean ret;
+
+		ret = prop->value > info->date_t;
+
+		/* debug output */
+		if (debug_filtering_session
+				&& prefs_common.filtering_debug_level >= FILTERING_DEBUG_LEVEL_HIGH) {
+			if (ret) {
+				log_print(LOG_DEBUG_FILTERING,
+						"message date [ %ld ] is before [ %d ]\n",
+						info->date_t, prop->value);
+			} else {
+				log_print(LOG_DEBUG_FILTERING,
+						"message date [ %ld ] is not before [ %d ]\n",
+						info->date_t, prop->value);
+			}
+		}
+		return ret;
+	}
 	case MATCHCRITERIA_SCORE_GREATER:
 	{
 		gboolean ret = (info->score > prop->value);
@@ -1277,19 +1330,6 @@ void matcherlist_free(MatcherList *cond)
 	g_free(cond);
 }
 
-/*!
- *\brief	Skip all headers in a message file
- *
- *\param	fp Message file
- */
-static void matcherlist_skip_headers(FILE *fp)
-{
-	gchar *buf = NULL;
-
-	while (procheader_get_one_field(&buf, fp, NULL) != -1)
-		g_free(buf);
-}
-
 /*!
  *\brief	Check if a header matches a matcher condition
  *
@@ -1584,7 +1624,7 @@ static gboolean matcherlist_match_binary_content(MatcherList *matchers, MimeInfo
 	if (!outfp)
 		return FALSE;
 
-	while (fgets(buf, sizeof(buf), outfp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), outfp) != NULL) {
 		strretchomp(buf);
 
 		for (l = matchers->matchers ; l != NULL ; l = g_slist_next(l)) {
@@ -1625,14 +1665,14 @@ static gboolean matcherlist_match_binary_content(MatcherList *matchers, MimeInfo
 			 * no need to check the others. */
 			if (matcher->result && matcher->done) {
 				if (!matchers->bool_and) {
-					fclose(outfp);
+					claws_fclose(outfp);
 					return TRUE;
 				}
 			}
 		}
 	}
 
-	fclose(outfp);
+	claws_fclose(outfp);
 	return FALSE;
 }
 
@@ -1784,8 +1824,8 @@ static gboolean matcherlist_match_file(MatcherList *matchers, MsgInfo *info,
 	if (file == NULL)
 		return FALSE;
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = claws_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "claws_fopen");
 		g_free(file);
 		return result;
 	}
@@ -1796,7 +1836,7 @@ static gboolean matcherlist_match_file(MatcherList *matchers, MsgInfo *info,
 		if (matcherlist_match_headers(matchers, fp))
 			read_body = FALSE;
 	} else {
-		matcherlist_skip_headers(fp);
+		procheader_skip_headers(fp);
 	}
 
 	/* read the body */
@@ -1827,7 +1867,7 @@ static gboolean matcherlist_match_file(MatcherList *matchers, MsgInfo *info,
 
 	g_free(file);
 
-	fclose(fp);
+	claws_fclose(fp);
 	
 	return result;
 }
@@ -1910,6 +1950,8 @@ gboolean matcherlist_match(MatcherList *matchers, MsgInfo *info)
 		case MATCHCRITERIA_AGE_LOWER:
 		case MATCHCRITERIA_AGE_GREATER_HOURS:
 		case MATCHCRITERIA_AGE_LOWER_HOURS:
+		case MATCHCRITERIA_DATE_AFTER:
+		case MATCHCRITERIA_DATE_BEFORE:
 		case MATCHCRITERIA_NEWSGROUPS:
 		case MATCHCRITERIA_NOT_NEWSGROUPS:
 		case MATCHCRITERIA_MESSAGEID:
@@ -2102,6 +2144,8 @@ gchar *matcherprop_to_string(MatcherProp *matcher)
 		return g_strdup(criteria_str);
 	case MATCHCRITERIA_TEST:
 	case MATCHCRITERIA_NOT_TEST:
+	case MATCHCRITERIA_DATE_AFTER:
+	case MATCHCRITERIA_DATE_BEFORE:
 		quoted_expr = matcher_quote_str(matcher->expr);
 		matcher_str = g_strdup_printf("%s \"%s\"",
 					      criteria_str, quoted_expr);
@@ -2386,42 +2430,42 @@ static int prefs_filtering_write(FILE *fp, GSList *prefs_filtering)
 			continue;
 
 		if (prop->enabled) {
-			if (fputs("enabled ", fp) == EOF) {
-				FILE_OP_ERROR("filtering config", "fputs");
+			if (claws_fputs("enabled ", fp) == EOF) {
+				FILE_OP_ERROR("filtering config", "claws_fputs");
 				return -1;
 			}
 		} else {
-			if (fputs("disabled ", fp) == EOF) {
-				FILE_OP_ERROR("filtering config", "fputs");
+			if (claws_fputs("disabled ", fp) == EOF) {
+				FILE_OP_ERROR("filtering config", "claws_fputs");
 				return -1;
 			}
 		}
 
-		if (fputs("rulename \"", fp) == EOF) {
-			FILE_OP_ERROR("filtering config", "fputs");
+		if (claws_fputs("rulename \"", fp) == EOF) {
+			FILE_OP_ERROR("filtering config", "claws_fputs");
 			g_free(filtering_str);
 			return -1;
 		}
 		tmp_name = prop->name;
 		while (tmp_name && *tmp_name != '\0') {
 			if (*tmp_name != '"') {
-				if (fputc(*tmp_name, fp) == EOF) {
-					FILE_OP_ERROR("filtering config", "fputs || fputc");
+				if (claws_fputc(*tmp_name, fp) == EOF) {
+					FILE_OP_ERROR("filtering config", "claws_fputs || claws_fputc");
 					g_free(filtering_str);
 					return -1;
 				}
 			} else if (*tmp_name == '"') {
-				if (fputc('\\', fp) == EOF ||
-				    fputc('"', fp) == EOF) {
-					FILE_OP_ERROR("filtering config", "fputs || fputc");
+				if (claws_fputc('\\', fp) == EOF ||
+				    claws_fputc('"', fp) == EOF) {
+					FILE_OP_ERROR("filtering config", "claws_fputs || claws_fputc");
 					g_free(filtering_str);
 					return -1;
 				}
 			}
 			tmp_name ++;
 		}
-		if (fputs("\" ", fp) == EOF) {
-			FILE_OP_ERROR("filtering config", "fputs");
+		if (claws_fputs("\" ", fp) == EOF) {
+			FILE_OP_ERROR("filtering config", "claws_fputs");
 			g_free(filtering_str);
 			return -1;
 		}
@@ -2430,17 +2474,17 @@ static int prefs_filtering_write(FILE *fp, GSList *prefs_filtering)
 			gchar *tmp = NULL;
 
 			tmp = g_strdup_printf("account %d ", prop->account_id);
-			if (fputs(tmp, fp) == EOF) {
-				FILE_OP_ERROR("filtering config", "fputs");
+			if (claws_fputs(tmp, fp) == EOF) {
+				FILE_OP_ERROR("filtering config", "claws_fputs");
 				g_free(tmp);
 				return -1;
 			}
 			g_free(tmp);
 		}
 
-		if(fputs(filtering_str, fp) == EOF ||
-		    fputc('\n', fp) == EOF) {
-			FILE_OP_ERROR("filtering config", "fputs || fputc");
+		if(claws_fputs(filtering_str, fp) == EOF ||
+		    claws_fputc('\n', fp) == EOF) {
+			FILE_OP_ERROR("filtering config", "claws_fputs || claws_fputc");
 			g_free(filtering_str);
 			return -1;
 		}
@@ -2488,7 +2532,7 @@ static gboolean prefs_matcher_write_func(GNode *node, gpointer d)
 			data->error = TRUE;
 			goto fail;
 		}
-		if (fputc('\n', data->fp) == EOF) {
+		if (claws_fputc('\n', data->fp) == EOF) {
 			data->error = TRUE;
 			goto fail;
 		}
@@ -2526,19 +2570,19 @@ static int prefs_matcher_save(FILE *fp)
         /* pre global rules */
         if (fprintf(fp, "[preglobal]\n") < 0 ||
             prefs_filtering_write(fp, pre_global_processing) < 0 ||
-            fputc('\n', fp) == EOF)
+            claws_fputc('\n', fp) == EOF)
 		return -1;
 
         /* post global rules */
         if (fprintf(fp, "[postglobal]\n") < 0 ||
             prefs_filtering_write(fp, post_global_processing) < 0 ||
-            fputc('\n', fp) == EOF)
+            claws_fputc('\n', fp) == EOF)
 		return -1;
         
         /* filtering rules */
 	if (fprintf(fp, "[filtering]\n") < 0 ||
             prefs_filtering_write(fp, filtering_rules) < 0 ||
-            fputc('\n', fp) == EOF)
+            claws_fputc('\n', fp) == EOF)
 		return -1;
 
 	return 0;
@@ -2586,11 +2630,11 @@ void prefs_matcher_read_config(void)
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, MATCHER_RC, NULL);
 
-	f = g_fopen(rcpath, "rb");
+	f = claws_fopen(rcpath, "rb");
 	g_free(rcpath);
 
 	if (f != NULL) {
 		matcher_parser_start_parsing(f);
-		fclose(matcher_parserin);
+		claws_fclose(matcher_parserin);
 	}
 }
