@@ -28,6 +28,7 @@
 #include <fancy_viewer.h>
 #include <fancy_prefs.h>
 #include <alertpanel.h>
+#include <file-utils.h>
 
 #include <printing.h>
 #include <webkit/webkithittestresult.h>
@@ -70,10 +71,6 @@ static void *download_file_curl (void *data);
 static void download_file_cb(GtkWidget *widget, FancyViewer *viewer);
 static gboolean fancy_set_contents(FancyViewer *viewer, gboolean use_defaults);
 
-#if !WEBKIT_CHECK_VERSION (1,5,1)
-gchar* webkit_web_view_get_selected_text(WebKitWebView* web_view);
-#endif
-
 /*------*/
 static GtkWidget *fancy_get_widget(MimeViewer *_viewer)
 {
@@ -343,7 +340,6 @@ static gchar *fancy_get_selection (MimeViewer *_viewer)
 {
 	debug_print("fancy_get_selection\n");
 	FancyViewer *viewer = (FancyViewer *) _viewer;
-#if WEBKIT_CHECK_VERSION(1,5,1)
 	viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
 	viewer->window = webkit_dom_document_get_default_view (viewer->doc);
 	viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
@@ -353,9 +349,6 @@ static gchar *fancy_get_selection (MimeViewer *_viewer)
 	if (viewer->range == NULL)
 		return NULL;
 	gchar *sel = webkit_dom_range_get_text (viewer->range);
-#else
-	gchar *sel = webkit_web_view_get_selected_text(viewer->view);
-#endif
 	if (!viewer->view || strlen(sel) == 0) {
 		g_free(sel);
 		return NULL;
@@ -581,14 +574,10 @@ static void load_finished_cb(WebKitWebView *view, gint progress,
 }
 
 static void over_link_cb(WebKitWebView *view, const gchar *wtf,
-			 const gchar *link, FancyViewer *viewer, void *wtfa)
+		const gchar *link, FancyViewer *viewer, void *wtfa)
 {
+	/* Display the link in the bottom statusbar. */
 	gtk_label_set_text(GTK_LABEL(viewer->l_link), link);
-	g_free(viewer->cur_link);
-	viewer->cur_link = NULL;
-	if(link) {
-		viewer->cur_link = g_strdup(link);
-	}
 }
 
 static void load_progress_cb(WebKitWebView *view, GParamSpec* pspec,
@@ -631,15 +620,11 @@ static void search_the_web_cb(GtkWidget *widget, FancyViewer *viewer)
 	debug_print("Clicked on Search on Web\n");
 	if (webkit_web_view_has_selection(viewer->view)) {
 		gchar *search;
-#if WEBKIT_CHECK_VERSION(1,5,1)
 		viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
 		viewer->window = webkit_dom_document_get_default_view (viewer->doc);
 		viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
 		viewer->range = webkit_dom_dom_selection_get_range_at(viewer->selection, 0, NULL);
 		gchar *tmp = webkit_dom_range_get_text (viewer->range);
-#else
-		gchar *tmp = webkit_web_view_get_selected_text(viewer->view);
-#endif
 		search = g_strconcat(GOOGLE_SEARCH, tmp, NULL);
 
 		webkit_web_view_load_uri(viewer->view, search);
@@ -660,11 +645,11 @@ static size_t download_file_curl_write_cb(void *buffer, size_t size,
 {
 	FancyViewer *viewer = (FancyViewer *)data;
 	if (!viewer->stream) {
-		viewer->stream = fopen(viewer->curlfile, "wb");
+		viewer->stream = claws_fopen(viewer->curlfile, "wb");
 		if (!viewer->stream)
 			return -1;
 	}
-	return fwrite(buffer, size, nmemb, viewer->stream);
+	return claws_fwrite(buffer, size, nmemb, viewer->stream);
 }
 static void *download_file_curl (void *data)
 {
@@ -686,7 +671,7 @@ static void *download_file_curl (void *data)
 		if (CURLE_OK != res)
 			alertpanel_error(_("An error occurred: %d\n"), res);
 		if (viewer->stream)
-			fclose(viewer->stream);
+			claws_safe_fclose(viewer->stream);
 		curl_global_cleanup();
 	}
 #ifdef USE_PTHREAD
@@ -828,13 +813,35 @@ static void viewer_menu_handler(GtkWidget *menuitem, FancyViewer *viewer)
 	}
 }
 
-static gboolean populate_popup_cb (WebKitWebView *view, GtkWidget *menu,
-				   FancyViewer *viewer)
+static gboolean context_menu_cb (WebKitWebView *view, GtkWidget *menu,
+		WebKitHitTestResult *hit_test_result,
+		gboolean triggered_with_keyboard,
+		gpointer user_data)
 {
+	FancyViewer *viewer = (FancyViewer *)user_data;
 	Plugin *plugin = plugin_get_loaded_by_name("RSSyl");
+	WebKitHitTestResultContext context;
+	gchar *link_uri = NULL;
+
+	g_object_get(G_OBJECT(hit_test_result),
+			"context", &context,
+			"link-uri", &link_uri,
+			NULL);
+
+	debug_print("context %d, link-uri '%s'\n", context,
+			(link_uri != NULL ? link_uri : "(null)"));
+	if (context & WEBKIT_HIT_TEST_RESULT_CONTEXT_LINK &&
+			link_uri != NULL) {
+		if (viewer->cur_link != NULL)
+			g_free(viewer->cur_link);
+		/* g_object_get() already made a copy, no need to strdup() here */
+		viewer->cur_link = link_uri;
+	}
+
 	gtk_container_foreach(GTK_CONTAINER(menu),
 			      (GtkCallback)viewer_menu_handler,
 			      viewer);
+
 	if (plugin) {
 		GtkWidget *rssyl = gtk_image_menu_item_new_with_label(_("Import feed"));
 		GtkWidget *img = gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU);
@@ -845,7 +852,8 @@ static gboolean populate_popup_cb (WebKitWebView *view, GtkWidget *menu,
 				 G_CALLBACK(import_feed_cb),
 				 (gpointer *) viewer);
 	}
-	return TRUE;
+
+	return FALSE;
 }
 
 static gint keypress_events_cb (GtkWidget *widget, GdkEventKey *event,
@@ -871,8 +879,6 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 				   FancyViewer *viewer)
 {
 	if (ev->button.button == 1 && viewer->cur_link && viewer->override_prefs_external) {
-#if WEBKIT_CHECK_VERSION(1,9,3)
-		/* The x and y properties were added in 1.9.3 */
 		gint x, y;
 		WebKitHitTestResult *result;
 		result = webkit_web_view_get_hit_test_result(view, (GdkEventButton *)ev);
@@ -885,7 +891,6 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 		 * want to open the link. */
 		if ((x != viewer->click_x || y != viewer->click_y))
 			return FALSE;
-#endif
 
 		open_uri(viewer->cur_link, prefs_common_get_uri_cmd());
 		return TRUE;
@@ -896,27 +901,36 @@ static gboolean release_button_cb (WebKitWebView *view, GdkEvent *ev,
 static gboolean press_button_cb (WebKitWebView *view, GdkEvent *ev,
 		FancyViewer *viewer)
 {
-#if WEBKIT_CHECK_VERSION(1,5,1)
 	gint type = 0;
+	gchar *link = NULL;
+
 	WebKitHitTestResult *result =
 		webkit_web_view_get_hit_test_result(view, (GdkEventButton *)ev);
 
 	g_object_get(G_OBJECT(result),
 			"context", &type,
-# if WEBKIT_CHECK_VERSION(1,9,3)
-			"x", &viewer->click_x, "y", &viewer->click_y,
-# endif /* 1.9.3 */
+			"x", &viewer->click_x,
+			"y", &viewer->click_y,
+			"link-uri", &link,
 			NULL);
 
 	if (type & WEBKIT_HIT_TEST_RESULT_CONTEXT_SELECTION)
 		return FALSE;
 
+	if (viewer->cur_link) {
+		g_free(viewer->cur_link);
+		viewer->cur_link = NULL;
+	}
+	if (link != NULL) {
+		debug_print("press on %s\n", link);
+		viewer->cur_link = link; /* g_context returned a newly-allocated string */
+	}
+
 	viewer->doc = webkit_web_view_get_dom_document(WEBKIT_WEB_VIEW(viewer->view));
 	viewer->window = webkit_dom_document_get_default_view (viewer->doc);
 	viewer->selection = webkit_dom_dom_window_get_selection (viewer->window);
 	if (viewer->selection != NULL)
 		webkit_dom_dom_selection_empty(viewer->selection);
-#endif /* 1.5.1 */
 	return FALSE;
 }
 
@@ -937,7 +951,6 @@ static void zoom_out_cb(GtkWidget *widget, GdkEvent *ev, FancyViewer *viewer)
 	webkit_web_view_zoom_out(viewer->view);
 }
 
-#if WEBKIT_CHECK_VERSION (1,7,5)
 static void resource_load_failed_cb(WebKitWebView     *web_view,
 				    WebKitWebFrame    *web_frame,
 				    WebKitWebResource *web_resource,
@@ -946,7 +959,6 @@ static void resource_load_failed_cb(WebKitWebView     *web_view,
 {
 	debug_print("Loading error: %s\n", error->message);
 }
-#endif
 
 static MimeViewer *fancy_viewer_create(void)
 {
@@ -1063,7 +1075,7 @@ static MimeViewer *fancy_viewer_create(void)
 	g_signal_connect(G_OBJECT(viewer->view), "load-finished",
 			 G_CALLBACK(load_finished_cb), viewer);
 	g_signal_connect(G_OBJECT(viewer->view), "hovering-over-link",
-			 G_CALLBACK(over_link_cb), viewer);
+			G_CALLBACK(over_link_cb), viewer);
 
 	g_signal_connect(G_OBJECT(viewer->view), "notify::progress",
 			 G_CALLBACK(load_progress_cb), viewer);
@@ -1075,8 +1087,8 @@ static MimeViewer *fancy_viewer_create(void)
 
 	g_signal_connect(G_OBJECT(viewer->view), "resource-request-starting",
 			G_CALLBACK(resource_request_starting_cb), viewer);
-	g_signal_connect(G_OBJECT(viewer->view), "populate-popup",
-			 G_CALLBACK(populate_popup_cb), viewer);
+	g_signal_connect(G_OBJECT(viewer->view), "context-menu",
+			G_CALLBACK(context_menu_cb), viewer);
 	g_signal_connect(G_OBJECT(viewer->view), "button-press-event",
 			 G_CALLBACK(press_button_cb), viewer);
 	g_signal_connect(G_OBJECT(viewer->view), "button-release-event",
@@ -1094,10 +1106,8 @@ static MimeViewer *fancy_viewer_create(void)
 	g_signal_connect(G_OBJECT(viewer->view), "key_press_event",
 			 G_CALLBACK(keypress_events_cb), viewer);
 
-#if WEBKIT_CHECK_VERSION (1,7,5)
 	g_signal_connect(G_OBJECT(viewer->view), "resource-load-failed",
 			 G_CALLBACK(resource_load_failed_cb), viewer);
-#endif
 
 	viewer->filename = NULL;
 	return (MimeViewer *) viewer;
