@@ -1,5 +1,5 @@
 /*
- * Claws-Mail-- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2004 Hiroyuki Yamamoto
  * This file (C) 2005 Andrej Kacian <andrej@kacian.sk>
  *
@@ -33,7 +33,6 @@
 #include <folder.h>
 #include <procmsg.h>
 #include <localfolder.h>
-#include <common/utils.h>
 #include <main.h>
 #include <mh.h>
 #include <xml.h>
@@ -41,6 +40,7 @@
 #include <prefs_common.h>
 #include <prefs_toolbar.h>
 #include <utils.h>
+#include <file-utils.h>
 
 /* Local includes */
 #include "libfeed/feeditem.h"
@@ -831,6 +831,7 @@ static gint rssyl_remove_msg(Folder *folder, FolderItem *item, gint num)
 {
 	gboolean need_scan = FALSE;
 	gchar *file, *tmp;
+	RFolderItem *ritem = (RFolderItem *)item;
 
 	g_return_val_if_fail(item != NULL, -1);
 
@@ -849,7 +850,10 @@ static gint rssyl_remove_msg(Folder *folder, FolderItem *item, gint num)
 	}
 	g_free(tmp);
 
-	rssyl_deleted_add((RFolderItem *)item, file);
+	rssyl_deleted_update(ritem);
+	rssyl_deleted_add(ritem, file);
+	rssyl_deleted_store(ritem);
+	rssyl_deleted_free(ritem);
 
 	if( g_unlink(file) < 0 ) {
 		FILE_OP_ERROR(file, "unlink");
@@ -864,6 +868,52 @@ static gint rssyl_remove_msg(Folder *folder, FolderItem *item, gint num)
 	return 0;
 }
 
+static gint rssyl_remove_msgs(Folder *folder, FolderItem *item,
+		MsgInfoList *msglist, GHashTable *relation)
+{
+	gboolean need_scan = FALSE;
+	MsgInfoList *cur;
+	gchar *file;
+	gint processed = 0;
+
+	RFolderItem *ritem = (RFolderItem *)item;
+
+	g_return_val_if_fail(item != NULL, -1);
+
+	need_scan = mh_get_class()->scan_required(folder, item);
+
+	rssyl_deleted_update(ritem);
+
+	for (cur = msglist; cur != NULL; cur = cur->next) {
+		MsgInfo *msginfo = (MsgInfo *)cur->data;
+
+		if (msginfo == NULL)
+			continue;
+
+		file = rssyl_fetch_msg(folder, item, msginfo->msgnum);
+		if (file == NULL)
+			continue;
+
+		rssyl_deleted_add(ritem, file);
+
+		if (claws_unlink(file) < 0) {
+			FILE_OP_ERROR(file, "unlink");
+			g_free(file);
+		}
+
+		processed++;
+	}
+
+	if (processed > 0)
+		rssyl_deleted_store(ritem);
+	rssyl_deleted_free(ritem);
+
+	if (!need_scan)
+		item->mtime = time(NULL);
+
+	return processed;
+}
+
 static gboolean rssyl_subscribe_uri(Folder *folder, const gchar *uri)
 {
 	if (folder->klass != rssyl_folder_get_class())
@@ -978,7 +1028,7 @@ FolderClass *rssyl_folder_get_class()
 		rssyl_class.add_msg = rssyl_add_msg;
 		rssyl_class.add_msgs = rssyl_add_msgs;
 		rssyl_class.remove_msg = rssyl_remove_msg;
-		rssyl_class.remove_msgs = NULL;
+		rssyl_class.remove_msgs = rssyl_remove_msgs;
 		rssyl_class.is_msg_changed = rssyl_is_msg_changed;
 //		rssyl_class.change_flags = rssyl_change_flags;
 		rssyl_class.change_flags = NULL;
