@@ -4,11 +4,14 @@
 #include <glib.h>
 
 #include <folder.h>
+#include <passwordstore.h>
 
 #include "libfeed/feed.h"
 
+#define PLUGIN_NAME "RSSyl"
+
 /* Name of directory in rcdir where RSSyl will store its data. */
-#define RSSYL_DIR		"RSSyl"
+#define RSSYL_DIR		PLUGIN_NAME
 
 /* Folder name for a new feed, before it is parsed for the first time. */
 #define RSSYL_NEW_FOLDER_NAME		"NewFeed"
@@ -97,4 +100,9 @@ FolderItem *rssyl_get_root_folderitem(FolderItem *item);
 #define IS_RSSYL_FOLDER_ITEM(item) \
 	(item->folder->klass == rssyl_folder_get_class())
 
+#define rssyl_passwd_set(ritem, pwd) \
+	passwd_store_set(PWS_PLUGIN, PLUGIN_NAME, ritem->url, pwd, FALSE)
+#define rssyl_passwd_get(ritem) \
+	passwd_store_get(PWS_PLUGIN, PLUGIN_NAME, ritem->url)
+
 #endif /* __RSSYL_H */
