@@ -51,6 +51,7 @@
 #include "prefs_common.h"
 #include "alertpanel.h"
 #include "addr_compl.h"
+#include "file-utils.h"
 
 #ifdef HAVE_SYSEXITS_H
 #include <sysexits.h>
@@ -253,7 +254,7 @@ static gboolean mail_filtering_hook(gpointer source, gpointer data)
 		
 		if (whitelisted) {
 			debug_print("message is ham (whitelisted)\n");
-			fclose(fp);
+			claws_fclose(fp);
 			return FALSE;
 		}
 	}
@@ -291,7 +292,7 @@ static gboolean mail_filtering_hook(gpointer source, gpointer data)
 			g_main_context_iteration(NULL, TRUE);
 	}
 
-	fclose(fp);
+	claws_fclose(fp);
 
 	if (is_spam) {
 		debug_print("message is spam\n");
@@ -388,7 +389,7 @@ gchar* spamassassin_create_tmp_spamc_wrapper(gboolean spam)
 						config.username, config.timeout,
 						config.max_size * 1024, config.compress?"-z":"",
 						spam?"spam":"ham");
-		if (str_write_to_file(contents, fname) < 0) {
+		if (str_write_to_file(contents, fname, TRUE) < 0) {
 			g_free(fname);
 			fname = NULL;
 		}
