@@ -49,6 +49,7 @@
 #include "timing.h"
 #include "inc.h"
 #include "privacy.h"
+#include "file-utils.h"
 
 extern SessionStats session_stats;
 
@@ -495,8 +496,8 @@ FILE *procmsg_open_message(MsgInfo *msginfo)
 			return NULL;
 	}
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = claws_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "claws_fopen");
 		g_free(file);
 		return NULL;
 	}
@@ -506,7 +507,7 @@ FILE *procmsg_open_message(MsgInfo *msginfo)
 	if (MSG_IS_QUEUED(msginfo->flags) || MSG_IS_DRAFT(msginfo->flags)) {
 		gchar buf[BUFFSIZE];
 
-		while (fgets(buf, sizeof(buf), fp) != NULL) {
+		while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 			/* new way */
 			if ((!strncmp(buf, "X-Claws-End-Special-Headers: 1",
 				strlen("X-Claws-End-Special-Headers:"))) ||
@@ -531,14 +532,11 @@ FILE *procmsg_open_message(MsgInfo *msginfo)
 
 gboolean procmsg_msg_exist(MsgInfo *msginfo)
 {
-	gchar *path;
 	gboolean ret;
 
 	if (!msginfo) return FALSE;
 
-	path = folder_item_get_path(msginfo->folder);
 	ret = !folder_item_is_msg_changed(msginfo->folder, msginfo);
-	g_free(path);
 
 	return ret;
 }
@@ -583,7 +581,7 @@ void procmsg_get_filter_keyword(MsgInfo *msginfo, gchar **header, gchar **key,
 		if ((fp = procmsg_open_message(msginfo)) == NULL)
 			return;
 		procheader_get_header_fields(fp, hentry);
-		fclose(fp);
+		claws_fclose(fp);
 
 #define SET_FILTER_KEY(hstr, idx)	\
 {					\
@@ -745,8 +743,8 @@ static PrefsAccount *procmsg_get_account_from_file(const gchar *file)
 	
 	cm_return_val_if_fail(file != NULL, NULL);
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = claws_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "claws_fopen");
 		return NULL;
 	}
 
@@ -760,7 +758,7 @@ static PrefsAccount *procmsg_get_account_from_file(const gchar *file)
 		g_free(buf);
 		buf = NULL;
 	}
-	fclose(fp);
+	claws_fclose(fp);
 	return mailac;
 }
 
@@ -1088,16 +1086,16 @@ gint procmsg_remove_special_headers(const gchar *in, const gchar *out)
 	FILE *fp, *outfp;
 	gchar buf[BUFFSIZE];
 	
-	if ((fp = g_fopen(in, "rb")) == NULL) {
-		FILE_OP_ERROR(in, "fopen");
+	if ((fp = claws_fopen(in, "rb")) == NULL) {
+		FILE_OP_ERROR(in, "claws_fopen");
 		return -1;
 	}
-	if ((outfp = g_fopen(out, "wb")) == NULL) {
-		FILE_OP_ERROR(out, "fopen");
-		fclose(fp);
+	if ((outfp = claws_fopen(out, "wb")) == NULL) {
+		FILE_OP_ERROR(out, "claws_fopen");
+		claws_fclose(fp);
 		return -1;
 	}
-	while (fgets(buf, sizeof(buf), fp) != NULL) {
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
 		/* new way */
 		if ((!strncmp(buf, "X-Claws-End-Special-Headers: 1",
 			strlen("X-Claws-End-Special-Headers:"))) ||
@@ -1115,16 +1113,16 @@ gint procmsg_remove_special_headers(const gchar *in, const gchar *out)
 			break;
 		}
 	}
-	while (fgets(buf, sizeof(buf), fp) != NULL) {
-		if (fputs(buf, outfp) == EOF) {
-			FILE_OP_ERROR(out, "fputs");
-			fclose(outfp);
-			fclose(fp);
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL) {
+		if (claws_fputs(buf, outfp) == EOF) {
+			FILE_OP_ERROR(out, "claws_fputs");
+			claws_fclose(outfp);
+			claws_fclose(fp);
 			return -1;
 		}
 	}
-	fclose(outfp);
-	fclose(fp);
+	claws_safe_fclose(outfp);
+	claws_fclose(fp);
 	return 0;
 }
 
@@ -1134,13 +1132,19 @@ gint procmsg_save_to_outbox(FolderItem *outbox, const gchar *file,
 	gint num;
 	MsgInfo *msginfo, *tmp_msginfo;
 	MsgFlags flag = {0, 0};
+	gchar *outbox_path = NULL;
 
-	debug_print("saving sent message...\n");
-
-	if (!outbox)
+	if (!outbox) {
+		debug_print("using default outbox\n");
 		outbox = folder_get_default_outbox();
+	}
+
 	cm_return_val_if_fail(outbox != NULL, -1);
 
+	outbox_path = folder_item_get_path(outbox);
+	debug_print("saving sent message to %s...\n", outbox_path);
+	g_free(outbox_path);
+
 	/* remove queueing headers */
 	if (is_queued) {
 		gchar tmp[MAXPATHLEN + 1];
@@ -1551,8 +1555,8 @@ static gint procmsg_send_message_queue_full(const gchar *file, gboolean keep_ses
 
 	cm_return_val_if_fail(file != NULL, -1);
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = claws_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "claws_fopen");
 		if (errstr) {
 			if (*errstr) g_free(*errstr);
 			*errstr = g_strdup_printf(_("Couldn't open file %s."), file);
@@ -1688,8 +1692,8 @@ send_mail:
     		/* write to temporary file */
     		tmp = g_strdup_printf("%s%cnntp%p", get_tmp_dir(),
                     	    G_DIR_SEPARATOR, file);
-    		if ((tmpfp = g_fopen(tmp, "wb")) == NULL) {
-            		FILE_OP_ERROR(tmp, "fopen");
+    		if ((tmpfp = claws_fopen(tmp, "wb")) == NULL) {
+            		FILE_OP_ERROR(tmp, "claws_fopen");
             		newsval = -1;
 			alertpanel_error(_("Couldn't create temporary file for news sending."));
     		} else {
@@ -1698,9 +1702,9 @@ send_mail:
 				g_warning("can't change file mode");
     			}
 
-			while ((newsval == 0) && fgets(buf, sizeof(buf), fp) != NULL) {
-				if (fputs(buf, tmpfp) == EOF) {
-					FILE_OP_ERROR(tmp, "fputs");
+			while ((newsval == 0) && claws_fgets(buf, sizeof(buf), fp) != NULL) {
+				if (claws_fputs(buf, tmpfp) == EOF) {
+					FILE_OP_ERROR(tmp, "claws_fputs");
 					newsval = -1;
 					if (errstr) {
 						if (*errstr) g_free(*errstr);
@@ -1708,7 +1712,7 @@ send_mail:
 					}
 				}
 			}
-			fclose(tmpfp);
+			claws_safe_fclose(tmpfp);
 
 			if (newsval == 0) {
 				debug_print("Sending message by news\n");
@@ -1727,7 +1731,7 @@ send_mail:
 		g_free(tmp);
 	}
 
-	fclose(fp);
+	claws_fclose(fp);
 
 	/* update session statistics */
 	if (mailval == 0 && newsval == 0) {
@@ -1742,13 +1746,21 @@ send_mail:
 
 	/* save message to outbox */
 	if (mailval == 0 && newsval == 0 && savecopyfolder) {
-		debug_print("saving sent message...\n");
+		debug_print("saving sent message to %s...\n", savecopyfolder);
 
 		if (!encrypt || !mailac->save_encrypted_as_clear_text) {
 			outbox = folder_find_item_from_identifier(savecopyfolder);
-			if (!outbox)
+			if (!outbox) {
+				gchar *id;
 				outbox = folder_get_default_outbox();
-
+				if (outbox != NULL) {
+					id = folder_item_get_identifier(outbox);
+					debug_print("%s not found, using %s\n", savecopyfolder, id);
+					g_free(id);
+				} else {
+					debug_print("could not find outbox\n");
+				}
+			}
 			/* Mail was not saved to outbox before encrypting, save it now. */
 			gboolean saved = FALSE;
 			*queued_removed = FALSE;
@@ -2330,26 +2342,26 @@ MsgInfo *procmsg_msginfo_new_from_mimeinfo(MsgInfo *src_msginfo, MimeInfo *mimei
 	MsgInfo *tmp_msginfo = NULL;
 	MsgFlags flags = {0, 0};
 	gchar *tmpfile = get_tmp_file();
-	FILE *fp = g_fopen(tmpfile, "wb");
+	FILE *fp = claws_fopen(tmpfile, "wb");
 	
 	if (!mimeinfo || mimeinfo->type != MIMETYPE_MESSAGE ||
 	    g_ascii_strcasecmp(mimeinfo->subtype, "rfc822")) {
 		g_warning("procmsg_msginfo_new_from_mimeinfo(): unsuitable mimeinfo");
 		if (fp) 
-			fclose(fp);
+			claws_fclose(fp);
 		g_free(tmpfile);
 		return NULL;
 	}
 	
 	if (fp && procmime_write_mimeinfo(mimeinfo, fp) >= 0) {
-		fclose(fp);
+		claws_safe_fclose(fp);
 		fp = NULL;
 		tmp_msginfo = procheader_parse_file(
 			tmpfile, flags, 
 			TRUE, FALSE);
 	}
 	if (fp)
-		fclose(fp);
+		claws_safe_fclose(fp);
 
 	if (tmp_msginfo != NULL) {
 		if (src_msginfo)
