@@ -30,6 +30,7 @@
 #include "utils.h"
 #include "gtkutils.h"
 #include "prefs_common.h"
+#include "file-utils.h"
 
 static void source_window_size_alloc_cb	(GtkWidget	*widget,
 					 GtkAllocation	*allocation);
@@ -148,8 +149,8 @@ void source_window_show_msg(SourceWindow *sourcewin, MsgInfo *msginfo)
 
 	cm_return_if_fail(file != NULL);
 
-	if ((fp = g_fopen(file, "rb")) == NULL) {
-		FILE_OP_ERROR(file, "fopen");
+	if ((fp = claws_fopen(file, "rb")) == NULL) {
+		FILE_OP_ERROR(file, "claws_fopen");
 		g_free(file);
 		return;
 	}
@@ -161,10 +162,10 @@ void source_window_show_msg(SourceWindow *sourcewin, MsgInfo *msginfo)
 	g_free(title);
 	g_free(file);
 
-	while (fgets(buf, sizeof(buf), fp) != NULL)
+	while (claws_fgets(buf, sizeof(buf), fp) != NULL)
 		source_window_append(sourcewin, buf);
 
-	fclose(fp);
+	claws_fclose(fp);
 }
 
 static void source_window_append(SourceWindow *sourcewin, const gchar *str)
@@ -202,15 +203,9 @@ static gint source_window_delete_cb(GtkWidget *widget, GdkEventAny *event,
 static gboolean key_pressed(GtkWidget *widget, GdkEventKey *event,
 			    SourceWindow *sourcewin)
 {
-
 	if (!event || !sourcewin) return FALSE;
-	
+
 	switch (event->keyval) {
-	case GDK_KEY_A:
-	case GDK_KEY_a:
-		if ((event->state & GDK_CONTROL_MASK) != 0)
-			gtk_editable_select_region(GTK_EDITABLE(sourcewin->text), 0, -1);
-		break;
 	case GDK_KEY_W:
 	case GDK_KEY_w:
 		if ((event->state & GDK_CONTROL_MASK) != 0)
