@@ -34,6 +34,7 @@
 #include <string.h>
 #include <ctype.h>
 
+#include "file-utils.h"
 #include "utils.h"
 #include "gtk/menu.h"
 #include "plugin.h"
@@ -238,8 +239,8 @@ static gchar *accountrc_tmpl =
 	"\n"
 	"#recvtype can be:\n"
 	"#0 for pop3\n"
-	"#3  for imap\n"
-	"#5  for a local mbox file\n"
+	"#2  for imap\n"
+	"#3  for a local mbox file\n"
 	"#recvtype=\n"
 	"\n"
 	"#you can use $DOMAIN here \n"
@@ -402,7 +403,7 @@ static void wizard_read_defaults(void)
 
 	rcpath = g_strconcat(get_rc_dir(), G_DIR_SEPARATOR_S, "accountrc.tmpl", NULL);
 	if (!is_file_exist(rcpath)) {
-		str_write_to_file(accountrc_tmpl, rcpath);
+		str_write_to_file(accountrc_tmpl, rcpath, TRUE);
 	}
 
 	prefs_read_config(template_params, "AccountTemplate", rcpath, NULL);
@@ -590,7 +591,7 @@ static void write_welcome_email(WizardWindow *wizard)
 	msg = g_strconcat(head, body, NULL);
 
 	if (inbox && inbox->total_msgs == 0
-	 && str_write_to_file(msg, file) >= 0) {
+	 && str_write_to_file(msg, file, TRUE) >= 0) {
 		MsgFlags flags = { MSG_UNREAD|MSG_NEW, 0};
 		folder_item_add_msg(inbox, file, &flags, FALSE);
 	}
